@@ -1,4 +1,4 @@
-from aiozk import exc
+from aiozk import exc, Deadline
 
 from .base_lock import BaseLock
 
@@ -6,10 +6,11 @@ from .base_lock import BaseLock
 class Lock(BaseLock):
 
     async def acquire(self, timeout=None):
+        deadline = Deadline(timeout)
         result = None
         while not result:
             try:
-                result = await self.wait_in_line("lock", timeout)
+                result = await self.wait_in_line("lock", deadline.timeout)
             except exc.SessionLost:
                 continue
         return result
